"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidSecrets = getValidSecrets;
const devkit_1 = require("@nx/devkit");
function getValidSecrets(secrets) {
    if (!secrets) {
        return [];
    }
    if (typeof secrets === 'string') {
        try {
            secrets = JSON.parse(secrets);
        }
        catch (_a) {
            throw new Error('Invalid JSON passed to secrets argument');
        }
    }
    if (!Array.isArray(secrets)) {
        secrets = Object.keys(secrets).map((secret) => `${secret}=${secrets[secret]}`);
    }
    return secrets.map((secret) => {
        if (secret.includes('=') && secret.includes(':')) {
            return secret;
        }
        devkit_1.logger.warn(`"${secret}" is not a valid secret! It should be in the following format "ENV_VAR_NAME=SECRET:VERSION"`);
        return false;
    }).filter(Boolean);
}
//# sourceMappingURL=get-valid-secrets.js.map